@@ -78,7 +78,7 @@ class PartialDependenceBase(Explainer, ABC):
         self.target_names = target_names
         self.verbose = verbose
 
-    def explain(self,  # type: ignore[override]
+    def explain(self,
                 X: np.ndarray,
                 features: Optional[List[Union[int, Tuple[int, int]]]] = None,
                 kind: Literal['average', 'individual', 'both'] = 'average',
@@ -417,10 +417,10 @@ class PartialDependenceBase(Explainer, ABC):
         if not isinstance(percentiles, Iterable) or len(percentiles) != 2:
             raise ValueError("`percentiles` must be a sequence of 2 elements.")
 
-        if not all(0 <= x <= 1 for x in percentiles):  # type: ignore[attr-defined]
+        if not all(0 <= x <= 1 for x in percentiles):
             raise ValueError("`percentiles` values must be in [0, 1].")
 
-        if percentiles[0] >= percentiles[1]:  # type: ignore[index]
+        if percentiles[0] >= percentiles[1]:
             raise ValueError("`percentiles[0]` must be strictly less than `percentiles[1]`.")
 
         if grid_resolution <= 1:
@@ -506,6 +506,17 @@ class PartialDependenceBase(Explainer, ABC):
         )
         return Explanation(meta=copy.deepcopy(self.meta), data=data)
 
+    def reset_predictor(self, predictor: Union[Callable[[np.ndarray], np.ndarray], BaseEstimator]) -> None:
+        """
+        Resets the predictor function or tree-based `sklearn` estimator.
+
+        Parameters
+        ----------
+        predictor
+            New predictor function or tree-based `sklearn` estimator.
+        """
+        self.predictor = predictor
+
 
 class PartialDependence(PartialDependenceBase):
     """ Black-box implementation of partial dependence for tabular datasets.
@@ -557,7 +568,7 @@ class PartialDependence(PartialDependenceBase):
                          target_names=target_names,
                          verbose=verbose)
 
-    def explain(self,  # type: ignore[override]
+    def explain(self,
                 X: np.ndarray,
                 features: Optional[List[Union[int, Tuple[int, int]]]] = None,
                 kind: Literal['average', 'individual', 'both'] = 'average',
@@ -1085,8 +1096,10 @@ def plot_pd(exp: Explanation,
     for ax_group in one_way_axs.values():
         min_val = min([ax_pd_lim[0] for _, ax_pd_lim in ax_group])
         max_val = max([ax_pd_lim[1] for _, ax_pd_lim in ax_group])
-        ax_group[0][0].get_shared_y_axes().join(ax_group[0][0], *[ax[0] for ax in ax_group[1:]])
-        ax_group[0][0].set_ylim(min_val, max_val)
+        axs = [ax[0] for ax in ax_group]
+        for ax in axs[1:]:
+            ax.sharey(axs[0])
+        axs[0].set_ylim(min_val, max_val)
 
     fig.set(**fig_kw)
     return axes
@@ -1109,12 +1122,12 @@ def _sample_ice(ice_values: np.ndarray, n_ice: Union[Literal['all'], int, List[i
 
     _, N = ice_values.shape
     if isinstance(n_ice, numbers.Integral):
-        if n_ice >= N:  # type: ignore[operator]
+        if n_ice >= N:
             logger.warning('`n_ice` is greater than the number of instances in the reference dataset. '
                            'Automatically setting `n_ice` to the number of instances in the reference dataset.')
             return ice_values
 
-        if n_ice <= 0:  # type: ignore[operator]
+        if n_ice <= 0:
             raise ValueError('`n_ice` must be an integer grater than 0.')
 
         indices = np.random.choice(a=N, size=n_ice, replace=False)
