@@ -494,7 +494,7 @@ class DistributedExplainer:
         self.target_fcn = default_target_fcn
         # check global scope for any specific target function
         if concatenate_results:
-            self.concatenate = concatenate_minibatches  # type: ignore[assignment]
+            self.concatenate = concatenate_minibatches
         if f"{algorithm}_target_fcn" in globals():
             self.target_fcn = globals()[f"{algorithm}_target_fcn"]
 
