@@ -59,8 +59,7 @@ class LanguageModel(abc.ABC):
             # set model (for performance reasons the `call` method is wrapped in tf.function)
             self.model = TFAutoModelForMaskedLM.from_pretrained(model_path)
 
-            # To understand the type: ignore see https://github.com/python/mypy/issues/2427
-            self.caller = tf.function(self.model.call, experimental_relax_shapes=True)  # type: ignore[assignment]
+            self.caller = tf.function(self.model.call, experimental_relax_shapes=True)
 
             # set tokenizer
             self.tokenizer = AutoTokenizer.from_pretrained(model_path)
@@ -77,8 +76,7 @@ class LanguageModel(abc.ABC):
         # set model (for performance reasons the `call` method is wrapped in tf.function)
         self.model = TFAutoModelForMaskedLM.from_pretrained(path, local_files_only=True)
 
-        # To understand the type: ignore see https://github.com/python/mypy/issues/2427
-        self.caller = tf.function(self.model.call, experimental_relax_shapes=True)  # type: ignore[assignment]
+        self.caller = tf.function(self.model.call, experimental_relax_shapes=True)
 
         # set tokenizer
         self.tokenizer = AutoTokenizer.from_pretrained(path, local_files_only=True)
